import * as React from 'react';
import { InputGroup } from "./InputGroup";
import { InputGroupItem } from "./InputGroupItem";
import { ensureEnum, brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgrInputGroupInputCollection } from './igr-input-group-input-collection';
import { CollectionAdapter } from "igniteui-react-core";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
import { InputGroupDisplayType_$type } from './InputGroupDisplayType';
import { ControlDisplayDensity_$type } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
export class IgrInputGroup extends React.Component {
    constructor(props) {
        super(props);
        this._wrapper = null;
        this.contentInputs = [];
        /**
        * The style mappings actually present in the treemap. Do not directly modify this array.
        * This array's contents can be modified by causing React to reproject the child content.
        * Or adding and removing ranges from the manual ranges collection on the ranges property.
        */
        this.actualInputs = [];
        this._inputs = null;
        this._inputsAdapter = null;
        this._implementation = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._contentChildrenManager = new ContentChildrenManager((ch) => ch.props.name || ch.key || ch.props.id, (ch) => ch.name || ch.key || ch.id, () => this._updateContentChildren());
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this._getMainRef = this._getMainRef.bind(this);
        var container;
        if (document) {
            container = document.createElement("div");
        }
        var root;
        root = container;
        if (container != null) {
            root = container;
        }
        this.requestRender = this.requestRender.bind(this);
        this._portalManager = new PortalManager("inputContent", this.requestRender);
        var ren = new ReactRenderer(root, document, true, {}, this._portalManager);
        this._wrapper = ren;
        this._container = this._wrapper.rootWrapper;
        this._container.setStyleProperty("display", "inline-block");
        var inputGroup = this.i;
        this._inputGroup = inputGroup;
        this._inputsAdapter = new CollectionAdapter(this.contentInputs, this.i.inputs, this.actualInputs, (c) => c.i, (i) => {
            if (this._container && this._container.getNativeElement().parentElement) {
                i._styling(this._container.getNativeElement(), this, this);
            }
        }, (i) => { });
        inputGroup.provideContainer(ren);
        if (props) {
            this.initializeProperties();
        }
    }
    _getMainRef(ref) {
        this._elRef = ref;
        if (this._elRef) {
            let mut = new MutationObserver((list) => {
                for (var mutation of list) {
                    if (mutation.type == 'childList') {
                        this.i.onChildrenMutated();
                    }
                }
            });
            mut.observe(this._elRef, {
                childList: true,
                subtree: true
            });
        }
    }
    _updateContentChildren() {
        this.contentInputs.length = 0;
        let contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        for (let i = 0; i < contentChildrenActual.length; i++) {
            if ((InputGroupItem.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentInputs.push(contentChildrenActual[i]);
            }
        }
        if (this._inputsAdapter !== null) {
            this._inputsAdapter.notifyContentChanged();
        }
    }
    /**
     * A collection of manually added style mappings for the treemap.
    */
    get inputs() {
        if (this._inputs === null) {
            let coll = new IgrInputGroupInputCollection();
            let inner = coll._innerColl;
            inner.addListener((sender, e) => {
                switch (e.action) {
                    case NotifyCollectionChangedAction.Add:
                        this._inputsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Remove:
                        this._inputsAdapter.removeManualItemAt(e.oldStartingIndex);
                        break;
                    case NotifyCollectionChangedAction.Replace:
                        this._inputsAdapter.removeManualItemAt(e.oldStartingIndex);
                        this._inputsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Reset:
                        this._inputsAdapter.clearManualItems();
                        break;
                }
            });
            this._inputs = coll;
        }
        return this._inputs;
    }
    render() {
        let children = this._contentChildrenManager.getChildren(this.props.children);
        this._portalManager.onRender(children);
        let div = React.createElement("div", {
            className: "ig-input-group igr-input-group",
            ref: this._getMainRef,
            children: children
        });
        return div;
    }
    requestRender() {
        if (this._initialized) {
            this.setState({});
        }
    }
    //private _getLabelPortal(element: DomWrapper, portalCallback: (portal: DomPortal) => void): void {
    //    this._portalManager.getPortal(element, "TemplateContent", portalCallback);
    //}
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    initializeProperties() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    // supports angular themes or custom properties set in CSS
    updateStyle() {
        this._styling(this._elRef, this);
    }
    componentWillUnmount() {
        this._inputGroup.destroy();
        this._wrapper.destroy();
    }
    componentDidMount() {
        this._elRef.appendChild(this._container.getNativeElement());
        this.initializeContent();
    }
    initializeContent() {
        this._styling(this._container.getNativeElement(), this);
        this.updateStyle();
    }
    createImplementation() {
        return new InputGroup();
    }
    get i() {
        return this._implementation;
    }
    /**
 * Gets or sets the display style to use for the button.
*/
    get type() {
        return this.i.j;
    }
    set type(v) {
        this.i.j = ensureEnum(InputGroupDisplayType_$type, v);
    }
    /**
     * Gets or sets the display density to use for the input group.
    */
    get density() {
        return this.i.h;
    }
    set density(v) {
        this.i.h = ensureEnum(ControlDisplayDensity_$type, v);
    }
    /**
     * Gets the actual display density to use for the input group.
    */
    get actualDensity() {
        return this.i.g;
    }
    set actualDensity(v) {
        this.i.g = ensureEnum(ControlDisplayDensity_$type, v);
    }
    /**
     * Gets or sets the base built in theme to use for the label.
    */
    get baseTheme() {
        return this.i.d;
    }
    set baseTheme(v) {
        this.i.d = ensureEnum(BaseControlTheme_$type, v);
    }
    get inputHasValue() {
        return this.i.ac;
    }
    /**
     * Gets the actual item background color.
    */
    get actualBorderColor() {
        return brushToString(this.i.oc);
    }
    set actualBorderColor(v) {
        this.i.oc = stringToBrush(v);
    }
    /**
     * Gets the actual item border color.
    */
    get actualFocusBorderColor() {
        return brushToString(this.i.od);
    }
    set actualFocusBorderColor(v) {
        this.i.od = stringToBrush(v);
    }
    /**
     * Gets the actual item border width.
    */
    get actualBorderWidth() {
        return this.i.b6;
    }
    set actualBorderWidth(v) {
        this.i.b6 = +v;
    }
    /**
     * Gets the actual item border width.
    */
    get actualFocusBorderWidth() {
        return this.i.b7;
    }
    set actualFocusBorderWidth(v) {
        this.i.b7 = +v;
    }
    /**
     * Gets actual corner radius to use the for the input group.
    */
    get actualCornerRadius() {
        return this.i.mj;
    }
    set actualCornerRadius(v) {
        this.i.mj = v;
    }
    /**
     * Gets the actual padding to use around the input area.
    */
    get actualContentPadding() {
        return this.i.sz;
    }
    set actualContentPadding(v) {
        this.i.sz = v;
    }
    /**
     * Gets the actual width to use the for the underline element.
    */
    get actualUnderlineWidth() {
        return this.i.cf;
    }
    set actualUnderlineWidth(v) {
        this.i.cf = +v;
    }
    /**
     * Gets the actual width to use the for the underline element.
    */
    get actualUnderlineRippleWidth() {
        return this.i.ce;
    }
    set actualUnderlineRippleWidth(v) {
        this.i.ce = +v;
    }
    /**
     * Gets the width to use the for the underline element when hovered.
    */
    get actualHoverUnderlineWidth() {
        return this.i.cb;
    }
    set actualHoverUnderlineWidth(v) {
        this.i.cb = +v;
    }
    /**
     * Gets the actual color to use the for the underline element.
    */
    get actualUnderlineColor() {
        return brushToString(this.i.og);
    }
    set actualUnderlineColor(v) {
        this.i.og = stringToBrush(v);
    }
    /**
     * Gets the actual color to use the for the underline ripple element.
    */
    get actualUnderlineRippleColor() {
        return brushToString(this.i.oh);
    }
    set actualUnderlineRippleColor(v) {
        this.i.oh = stringToBrush(v);
    }
    /**
     * Gets the actual color to use the for the underline element.
    */
    get actualHoverUnderlineColor() {
        return brushToString(this.i.of);
    }
    set actualHoverUnderlineColor(v) {
        this.i.of = stringToBrush(v);
    }
    /**
     * Gets the actual color to use the for the underline element when focused.
    */
    get actualFocusUnderlineColor() {
        return brushToString(this.i.oe);
    }
    set actualFocusUnderlineColor(v) {
        this.i.oe = stringToBrush(v);
    }
    /**
     * Gets the actual opacity to use the for the underline element.
    */
    get actualUnderlineOpacity() {
        return this.i.cc;
    }
    set actualUnderlineOpacity(v) {
        this.i.cc = +v;
    }
    /**
     * Gets the actual opacity to use the for the underline element when hovered.
    */
    get actualHoverUnderlineOpacity() {
        return this.i.ca;
    }
    set actualHoverUnderlineOpacity(v) {
        this.i.ca = +v;
    }
    /**
     * Gets the actual opacity to use the for the underline element when focused.
    */
    get actualFocusUnderlineOpacity() {
        return this.i.b8;
    }
    set actualFocusUnderlineOpacity(v) {
        this.i.b8 = +v;
    }
    /**
     * Gets the actual opacity to use the for the underline ripple element when focused.
    */
    get actualFocusUnderlineRippleOpacity() {
        return this.i.b9;
    }
    set actualFocusUnderlineRippleOpacity(v) {
        this.i.b9 = +v;
    }
    /**
     * Gets the actual opacity to use the for the underline ripple element.
    */
    get actualUnderlineRippleOpacity() {
        return this.i.cd;
    }
    set actualUnderlineRippleOpacity(v) {
        this.i.cd = +v;
    }
    /**
     * Gets the actual opacity to use the for the underline ripple element.
    */
    get actualBackgroundColor() {
        return brushToString(this.i.ob);
    }
    set actualBackgroundColor(v) {
        this.i.ob = stringToBrush(v);
    }
    /**
     * Gets or sets the border width to use for the border of the item group.
    */
    get borderWidth() {
        return this.i.cq;
    }
    set borderWidth(v) {
        this.i.cq = +v;
    }
    /**
     * Gets or sets the border width to use for the border of the item group when focused.
    */
    get focusBorderWidth() {
        return this.i.g8;
    }
    set focusBorderWidth(v) {
        this.i.g8 = +v;
    }
    /**
     * Gets or sets the color to use the border of the input group.
    */
    get borderColor() {
        return brushToString(this.i.oj);
    }
    set borderColor(v) {
        this.i.oj = stringToBrush(v);
    }
    /**
     * Gets or sets the corner radius to use the for the input group.
    */
    get cornerRadius() {
        return this.i.mn;
    }
    set cornerRadius(v) {
        this.i.mn = v;
    }
    /**
     * Gets or sets the padding to use around the input area.
    */
    get contentPadding() {
        return this.i.s3;
    }
    set contentPadding(v) {
        this.i.s3 = v;
    }
    /**
     * Gets or sets the width to use the for the underline element.
    */
    get underlineWidth() {
        return this.i.h0;
    }
    set underlineWidth(v) {
        this.i.h0 = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element.
    */
    get underlineRippleWidth() {
        return this.i.hz;
    }
    set underlineRippleWidth(v) {
        this.i.hz = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when hovered.
    */
    get hoverUnderlineWidth() {
        return this.i.hc;
    }
    set hoverUnderlineWidth(v) {
        this.i.hc = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element.
    */
    get underlineColor() {
        return brushToString(this.i.sr);
    }
    set underlineColor(v) {
        this.i.sr = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline ripple element.
    */
    get underlineRippleColor() {
        return brushToString(this.i.ss);
    }
    set underlineRippleColor(v) {
        this.i.ss = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element.
    */
    get hoverUnderlineColor() {
        return brushToString(this.i.sc);
    }
    set hoverUnderlineColor(v) {
        this.i.sc = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element.
    */
    get focusUnderlineColor() {
        return brushToString(this.i.sb);
    }
    set focusUnderlineColor(v) {
        this.i.sb = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element.
    */
    get underlineOpacity() {
        return this.i.hx;
    }
    set underlineOpacity(v) {
        this.i.hx = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element.
    */
    get hoverUnderlineOpacity() {
        return this.i.hb;
    }
    set hoverUnderlineOpacity(v) {
        this.i.hb = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element.
    */
    get focusUnderlineOpacity() {
        return this.i.g9;
    }
    set focusUnderlineOpacity(v) {
        this.i.g9 = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when focused.
    */
    get focusUnderlineRippleOpacity() {
        return this.i.ha;
    }
    set focusUnderlineRippleOpacity(v) {
        this.i.ha = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element.
    */
    get underlineRippleOpacity() {
        return this.i.hy;
    }
    set underlineRippleOpacity(v) {
        this.i.hy = +v;
    }
    /**
     * Gets or sets the background color to use for the input group.
    */
    get backgroundColor() {
        return brushToString(this.i.oi);
    }
    set backgroundColor(v) {
        this.i.oi = stringToBrush(v);
    }
    /**
     * Gets or sets the border width to use for the border of the item group when using type line.
    */
    get lineTypeBorderWidth() {
        return this.i.hd;
    }
    set lineTypeBorderWidth(v) {
        this.i.hd = +v;
    }
    /**
     * Gets or sets the border width to use for the border of the item group when focused when type is line.
    */
    get lineTypeFocusBorderWidth() {
        return this.i.he;
    }
    set lineTypeFocusBorderWidth(v) {
        this.i.he = +v;
    }
    /**
     * Gets or sets the focus color to use the border of the input group when type is line.
    */
    get lineTypeFocusBorderColor() {
        return brushToString(this.i.sf);
    }
    set lineTypeFocusBorderColor(v) {
        this.i.sf = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the border of the input group when type is line.
    */
    get lineTypeBorderColor() {
        return brushToString(this.i.se);
    }
    set lineTypeBorderColor(v) {
        this.i.se = stringToBrush(v);
    }
    /**
     * Gets or sets the corner radius to use the for the input group when type is line.
    */
    get lineTypeCornerRadius() {
        return this.i.m3;
    }
    set lineTypeCornerRadius(v) {
        this.i.m3 = v;
    }
    /**
     * Gets or sets the padding to use around the input area when type is line.
    */
    get lineTypeContentPadding() {
        return this.i.tj;
    }
    set lineTypeContentPadding(v) {
        this.i.tj = v;
    }
    /**
     * Gets or sets the width to use the for the underline element when type is line.
    */
    get lineTypeUnderlineWidth() {
        return this.i.hm;
    }
    set lineTypeUnderlineWidth(v) {
        this.i.hm = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when type is line.
    */
    get lineTypeUnderlineRippleWidth() {
        return this.i.hl;
    }
    set lineTypeUnderlineRippleWidth(v) {
        this.i.hl = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when hovered when type is line.
    */
    get lineTypeHoverUnderlineWidth() {
        return this.i.hi;
    }
    set lineTypeHoverUnderlineWidth(v) {
        this.i.hi = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is line.
    */
    get lineTypeUnderlineColor() {
        return brushToString(this.i.si);
    }
    set lineTypeUnderlineColor(v) {
        this.i.si = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline ripple element when type is line.
    */
    get lineTypeUnderlineRippleColor() {
        return brushToString(this.i.sj);
    }
    set lineTypeUnderlineRippleColor(v) {
        this.i.sj = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is line.
    */
    get lineTypeHoverUnderlineColor() {
        return brushToString(this.i.sh);
    }
    set lineTypeHoverUnderlineColor(v) {
        this.i.sh = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is line.
    */
    get lineTypeFocusUnderlineColor() {
        return brushToString(this.i.sg);
    }
    set lineTypeFocusUnderlineColor(v) {
        this.i.sg = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is line.
    */
    get lineTypeUnderlineOpacity() {
        return this.i.hj;
    }
    set lineTypeUnderlineOpacity(v) {
        this.i.hj = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is line.
    */
    get lineTypeHoverUnderlineOpacity() {
        return this.i.hh;
    }
    set lineTypeHoverUnderlineOpacity(v) {
        this.i.hh = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is line.
    */
    get lineTypeFocusUnderlineOpacity() {
        return this.i.hf;
    }
    set lineTypeFocusUnderlineOpacity(v) {
        this.i.hf = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when focused when type is line.
    */
    get lineTypeFocusUnderlineRippleOpacity() {
        return this.i.hg;
    }
    set lineTypeFocusUnderlineRippleOpacity(v) {
        this.i.hg = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when type is line.
    */
    get lineTypeUnderlineRippleOpacity() {
        return this.i.hk;
    }
    set lineTypeUnderlineRippleOpacity(v) {
        this.i.hk = +v;
    }
    /**
     * Gets or sets the background color to use for the input group when type is line.
    */
    get lineTypeBackgroundColor() {
        return brushToString(this.i.sd);
    }
    set lineTypeBackgroundColor(v) {
        this.i.sd = stringToBrush(v);
    }
    /**
     * Gets or sets the border width to use for the border of the item group when using type line.
    */
    get boxTypeBorderWidth() {
        return this.i.cr;
    }
    set boxTypeBorderWidth(v) {
        this.i.cr = +v;
    }
    /**
     * Gets or sets the border width to use for the border of the item group when focused when type is box.
    */
    get boxTypeFocusBorderWidth() {
        return this.i.cs;
    }
    set boxTypeFocusBorderWidth(v) {
        this.i.cs = +v;
    }
    /**
     * Gets or sets the focus color to use the border of the input group when type is box.
    */
    get boxTypeFocusBorderColor() {
        return brushToString(this.i.ot);
    }
    set boxTypeFocusBorderColor(v) {
        this.i.ot = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the border of the input group when type is box.
    */
    get boxTypeBorderColor() {
        return brushToString(this.i.os);
    }
    set boxTypeBorderColor(v) {
        this.i.os = stringToBrush(v);
    }
    /**
     * Gets or sets the corner radius to use the for the input group when type is box.
    */
    get boxTypeCornerRadius() {
        return this.i.ml;
    }
    set boxTypeCornerRadius(v) {
        this.i.ml = v;
    }
    /**
     * Gets or sets the padding to use around the input area when type is box.
    */
    get boxTypeContentPadding() {
        return this.i.s1;
    }
    set boxTypeContentPadding(v) {
        this.i.s1 = v;
    }
    /**
     * Gets or sets the width to use the for the underline element when type is box.
    */
    get boxTypeUnderlineWidth() {
        return this.i.c0;
    }
    set boxTypeUnderlineWidth(v) {
        this.i.c0 = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when type is box.
    */
    get boxTypeUnderlineRippleWidth() {
        return this.i.cz;
    }
    set boxTypeUnderlineRippleWidth(v) {
        this.i.cz = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when hovered when type is box.
    */
    get boxTypeHoverUnderlineWidth() {
        return this.i.cw;
    }
    set boxTypeHoverUnderlineWidth(v) {
        this.i.cw = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is box.
    */
    get boxTypeUnderlineColor() {
        return brushToString(this.i.ow);
    }
    set boxTypeUnderlineColor(v) {
        this.i.ow = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline ripple element when type is box.
    */
    get boxTypeUnderlineRippleColor() {
        return brushToString(this.i.ox);
    }
    set boxTypeUnderlineRippleColor(v) {
        this.i.ox = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is box.
    */
    get boxTypeHoverUnderlineColor() {
        return brushToString(this.i.ov);
    }
    set boxTypeHoverUnderlineColor(v) {
        this.i.ov = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is box.
    */
    get boxTypeFocusUnderlineColor() {
        return brushToString(this.i.ou);
    }
    set boxTypeFocusUnderlineColor(v) {
        this.i.ou = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is box.
    */
    get boxTypeUnderlineOpacity() {
        return this.i.cx;
    }
    set boxTypeUnderlineOpacity(v) {
        this.i.cx = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is box.
    */
    get boxTypeHoverUnderlineOpacity() {
        return this.i.cv;
    }
    set boxTypeHoverUnderlineOpacity(v) {
        this.i.cv = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is box.
    */
    get boxTypeFocusUnderlineOpacity() {
        return this.i.ct;
    }
    set boxTypeFocusUnderlineOpacity(v) {
        this.i.ct = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when focused when type is box.
    */
    get boxTypeFocusUnderlineRippleOpacity() {
        return this.i.cu;
    }
    set boxTypeFocusUnderlineRippleOpacity(v) {
        this.i.cu = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when type is box.
    */
    get boxTypeUnderlineRippleOpacity() {
        return this.i.cy;
    }
    set boxTypeUnderlineRippleOpacity(v) {
        this.i.cy = +v;
    }
    /**
     * Gets or sets the background color to use for the input group when type is box.
    */
    get boxTypeBackgroundColor() {
        return brushToString(this.i.or);
    }
    set boxTypeBackgroundColor(v) {
        this.i.or = stringToBrush(v);
    }
    /**
     * Gets or sets the border width to use for the border of the item group when using type line.
    */
    get borderTypeBorderWidth() {
        return this.i.cg;
    }
    set borderTypeBorderWidth(v) {
        this.i.cg = +v;
    }
    /**
     * Gets or sets the border width to use for the border of the item group when focused when type is border.
    */
    get borderTypeFocusBorderWidth() {
        return this.i.ch;
    }
    set borderTypeFocusBorderWidth(v) {
        this.i.ch = +v;
    }
    /**
     * Gets or sets the focus color to use the border of the input group when type is border.
    */
    get borderTypeFocusBorderColor() {
        return brushToString(this.i.om);
    }
    set borderTypeFocusBorderColor(v) {
        this.i.om = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the border of the input group when type is border.
    */
    get borderTypeBorderColor() {
        return brushToString(this.i.ol);
    }
    set borderTypeBorderColor(v) {
        this.i.ol = stringToBrush(v);
    }
    /**
     * Gets or sets the corner radius to use the for the input group when type is border.
    */
    get borderTypeCornerRadius() {
        return this.i.mk;
    }
    set borderTypeCornerRadius(v) {
        this.i.mk = v;
    }
    /**
     * Gets or sets the padding to use around the input area when type is border.
    */
    get borderTypeContentPadding() {
        return this.i.s0;
    }
    set borderTypeContentPadding(v) {
        this.i.s0 = v;
    }
    /**
     * Gets or sets the width to use the for the underline element when type is border.
    */
    get borderTypeUnderlineWidth() {
        return this.i.cp;
    }
    set borderTypeUnderlineWidth(v) {
        this.i.cp = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when type is border.
    */
    get borderTypeUnderlineRippleWidth() {
        return this.i.co;
    }
    set borderTypeUnderlineRippleWidth(v) {
        this.i.co = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when hovered when type is border.
    */
    get borderTypeHoverUnderlineWidth() {
        return this.i.cl;
    }
    set borderTypeHoverUnderlineWidth(v) {
        this.i.cl = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is border.
    */
    get borderTypeUnderlineColor() {
        return brushToString(this.i.op);
    }
    set borderTypeUnderlineColor(v) {
        this.i.op = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline ripple element when type is border.
    */
    get borderTypeUnderlineRippleColor() {
        return brushToString(this.i.oq);
    }
    set borderTypeUnderlineRippleColor(v) {
        this.i.oq = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is border.
    */
    get borderTypeHoverUnderlineColor() {
        return brushToString(this.i.oo);
    }
    set borderTypeHoverUnderlineColor(v) {
        this.i.oo = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is border.
    */
    get borderTypeFocusUnderlineColor() {
        return brushToString(this.i.on);
    }
    set borderTypeFocusUnderlineColor(v) {
        this.i.on = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is border.
    */
    get borderTypeUnderlineOpacity() {
        return this.i.cm;
    }
    set borderTypeUnderlineOpacity(v) {
        this.i.cm = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is border.
    */
    get borderTypeHoverUnderlineOpacity() {
        return this.i.ck;
    }
    set borderTypeHoverUnderlineOpacity(v) {
        this.i.ck = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is border.
    */
    get borderTypeFocusUnderlineOpacity() {
        return this.i.ci;
    }
    set borderTypeFocusUnderlineOpacity(v) {
        this.i.ci = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when focused when type is border.
    */
    get borderTypeFocusUnderlineRippleOpacity() {
        return this.i.cj;
    }
    set borderTypeFocusUnderlineRippleOpacity(v) {
        this.i.cj = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when type is border.
    */
    get borderTypeUnderlineRippleOpacity() {
        return this.i.cn;
    }
    set borderTypeUnderlineRippleOpacity(v) {
        this.i.cn = +v;
    }
    /**
     * Gets or sets the background color to use for the input group when type is border.
    */
    get borderTypeBackgroundColor() {
        return brushToString(this.i.ok);
    }
    set borderTypeBackgroundColor(v) {
        this.i.ok = stringToBrush(v);
    }
    /**
     * Gets or sets the search width to use for the border of the item group when using type line.
    */
    get searchTypeBorderWidth() {
        return this.i.hn;
    }
    set searchTypeBorderWidth(v) {
        this.i.hn = +v;
    }
    /**
     * Gets or sets the search width to use for the border of the item group when focused when type is search.
    */
    get searchTypeFocusBorderWidth() {
        return this.i.ho;
    }
    set searchTypeFocusBorderWidth(v) {
        this.i.ho = +v;
    }
    /**
     * Gets or sets the focus color to use the search of the input group when type is search.
    */
    get searchTypeFocusBorderColor() {
        return brushToString(this.i.sm);
    }
    set searchTypeFocusBorderColor(v) {
        this.i.sm = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the search of the input group when type is search.
    */
    get searchTypeBorderColor() {
        return brushToString(this.i.sl);
    }
    set searchTypeBorderColor(v) {
        this.i.sl = stringToBrush(v);
    }
    /**
     * Gets or sets the corner radius to use the for the input group when type is search.
    */
    get searchTypeCornerRadius() {
        return this.i.m4;
    }
    set searchTypeCornerRadius(v) {
        this.i.m4 = v;
    }
    /**
     * Gets or sets the padding to use around the input area when type is search.
    */
    get searchTypeContentPadding() {
        return this.i.tk;
    }
    set searchTypeContentPadding(v) {
        this.i.tk = v;
    }
    /**
     * Gets or sets the width to use the for the underline element when type is search.
    */
    get searchTypeUnderlineWidth() {
        return this.i.hw;
    }
    set searchTypeUnderlineWidth(v) {
        this.i.hw = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when type is search.
    */
    get searchTypeUnderlineRippleWidth() {
        return this.i.hv;
    }
    set searchTypeUnderlineRippleWidth(v) {
        this.i.hv = +v;
    }
    /**
     * Gets or sets the width to use the for the underline element when hovered when type is search.
    */
    get searchTypeHoverUnderlineWidth() {
        return this.i.hs;
    }
    set searchTypeHoverUnderlineWidth(v) {
        this.i.hs = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is search.
    */
    get searchTypeUnderlineColor() {
        return brushToString(this.i.sp);
    }
    set searchTypeUnderlineColor(v) {
        this.i.sp = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline ripple element when type is search.
    */
    get searchTypeUnderlineRippleColor() {
        return brushToString(this.i.sq);
    }
    set searchTypeUnderlineRippleColor(v) {
        this.i.sq = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is search.
    */
    get searchTypeHoverUnderlineColor() {
        return brushToString(this.i.so);
    }
    set searchTypeHoverUnderlineColor(v) {
        this.i.so = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is search.
    */
    get searchTypeFocusUnderlineColor() {
        return brushToString(this.i.sn);
    }
    set searchTypeFocusUnderlineColor(v) {
        this.i.sn = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use the for the underline element when type is search.
    */
    get searchTypeUnderlineOpacity() {
        return this.i.ht;
    }
    set searchTypeUnderlineOpacity(v) {
        this.i.ht = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is search.
    */
    get searchTypeHoverUnderlineOpacity() {
        return this.i.hr;
    }
    set searchTypeHoverUnderlineOpacity(v) {
        this.i.hr = +v;
    }
    /**
     * Gets or sets the color to use the for the underline element when type is search.
    */
    get searchTypeFocusUnderlineOpacity() {
        return this.i.hp;
    }
    set searchTypeFocusUnderlineOpacity(v) {
        this.i.hp = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when focused when type is search.
    */
    get searchTypeFocusUnderlineRippleOpacity() {
        return this.i.hq;
    }
    set searchTypeFocusUnderlineRippleOpacity(v) {
        this.i.hq = +v;
    }
    /**
     * Gets or sets the opacity to use the for the underline ripple element when type is search.
    */
    get searchTypeUnderlineRippleOpacity() {
        return this.i.hu;
    }
    set searchTypeUnderlineRippleOpacity(v) {
        this.i.hu = +v;
    }
    /**
     * Gets or sets the background color to use for the input group when type is search.
    */
    get searchTypeBackgroundColor() {
        return brushToString(this.i.sk);
    }
    set searchTypeBackgroundColor(v) {
        this.i.sk = stringToBrush(v);
    }
    /**
     * Gets or sets whether the input group is expanded or not.
    */
    get isExpanded() {
        return this.i.ae;
    }
    set isExpanded(v) {
        this.i.ae = ensureBool(v);
    }
    /**
     * Gets or sets whether the input group is hovered or not.
    */
    get isHovered() {
        return this.i.ag;
    }
    set isHovered(v) {
        this.i.ag = ensureBool(v);
    }
    /**
     * Gets or sets whether the input group is hovered or not.
    */
    get isFocused() {
        return this.i.af;
    }
    set isFocused(v) {
        this.i.af = ensureBool(v);
    }
    /**
     * Gets or sets whether the input group is expanded or not.
    */
    get actualIsExpanded() {
        return this.i.ab;
    }
    set actualIsExpanded(v) {
        this.i.ab = ensureBool(v);
    }
    /**
     * Gets or sets the color to use the hovered background of the inputs in the group.
    */
    get focusBorderColor() {
        return brushToString(this.i.sa);
    }
    set focusBorderColor(v) {
        this.i.sa = stringToBrush(v);
    }
    /**
     * Gets or sets the id to use for the checkbox.
    */
    get id() {
        return this.i.j7;
    }
    set id(v) {
        this.i.j7 = v;
    }
    /**
     * Gets or sets whether the checkbox is disabled.
    */
    get disabled() {
        return this.i.disabled;
    }
    set disabled(v) {
        this.i.disabled = ensureBool(v);
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("InputGroup");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    onDetachedFromUI() {
        this.i.onDetachedFromUI();
    }
    onAttachedToUI() {
        this.i.onAttachedToUI();
    }
}
//# sourceMappingURL=igr-input-group.js.map
