import * as React from 'react';
import { Input } from "./Input";
import { ensureEnum, brushToString, stringToBrush, ensureBool, NamePatcher, isValidProp, getModifiedProps } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrInputGroupItem } from './igr-input-group-item';
import { IgrInputChangeEventArgs } from './igr-input-change-event-args';
import { ControlDisplayDensity_$type } from "igniteui-react-core";
export class IgrInput extends IgrInputGroupItem {
    constructor(props) {
        super(props);
        this._wrapper = null;
        this._change = null;
        this._change_wrapped = null;
        this._changing = null;
        this._changing_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this._getMainRef = this._getMainRef.bind(this);
        var container;
        if (document) {
            container = document.createElement("div");
        }
        var root;
        root = container;
        if (container != null) {
            root = container;
        }
        this.requestRender = this.requestRender.bind(this);
        this._portalManager = new PortalManager("inputContent", this.requestRender);
        var ren = new ReactRenderer(root, document, true, {}, this._portalManager);
        this._wrapper = ren;
        this._container = this._wrapper.rootWrapper;
        this._container.setStyleProperty("display", "inline-block");
        this._container.setStyleProperty("vertical-align", "middle");
        var input = this.i;
        this._input = input;
        input.provideContainer(ren);
        if (props) {
            this.initializeProperties();
        }
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let div = React.createElement("div", {
            className: "ig-input igr-input",
            ref: this._getMainRef,
            children: children
        });
        return div;
    }
    requestRender() {
        if (this._initialized) {
            this.setState({});
        }
    }
    //private _getLabelPortal(element: DomWrapper, portalCallback: (portal: DomPortal) => void): void {
    //    this._portalManager.getPortal(element, "TemplateContent", portalCallback);
    //}
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    initializeProperties() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    // supports angular themes or custom properties set in CSS
    updateStyle() {
        this._styling(this._elRef, this);
    }
    componentWillUnmount() {
        this._input.destroy();
        this._wrapper.destroy();
    }
    componentDidMount() {
        this._elRef.appendChild(this._container.getNativeElement());
        this.initializeContent();
    }
    initializeContent() {
        this._styling(this._container.getNativeElement(), this);
        this.updateStyle();
    }
    createImplementation() {
        return new Input();
    }
    /**
                             * @hidden
                             */
    get i() {
        return this._implementation;
    }
    /**
 * Gets or sets the display density to use for the input.
*/
    get density() {
        return this.i.l;
    }
    set density(v) {
        this.i.l = ensureEnum(ControlDisplayDensity_$type, v);
    }
    /**
     * Gets the actual display density to use for the label.
    */
    get actualDensity() {
        return this.i.k;
    }
    set actualDensity(v) {
        this.i.k = ensureEnum(ControlDisplayDensity_$type, v);
    }
    /**
     * Gets the actual color to use for the text color.
    */
    get actualTextColor() {
        return brushToString(this.i.by);
    }
    set actualTextColor(v) {
        this.i.by = stringToBrush(v);
    }
    /**
     * Gets the actual hover color to use for the text.
    */
    get actualHoverTextColor() {
        return brushToString(this.i.bx);
    }
    set actualHoverTextColor(v) {
        this.i.bx = stringToBrush(v);
    }
    /**
     * Gets the text style to use for the button.
    */
    get actualTextStyle() {
        return this.i.t;
    }
    set actualTextStyle(v) {
        this.i.t = v;
    }
    /**
     * Gets or sets the color to use for the text.
    */
    get textColor() {
        return brushToString(this.i.b2);
    }
    set textColor(v) {
        this.i.b2 = stringToBrush(v);
    }
    /**
     * Gets or sets the use for the button.
    */
    get textStyle() {
        return this.i.v;
    }
    set textStyle(v) {
        this.i.v = v;
    }
    /**
     * Gets or sets the type to use for the input.
    */
    get type() {
        return this.i.a8;
    }
    set type(v) {
        this.i.a8 = v;
    }
    /**
     * Gets or sets the placeholder to use for the input.
    */
    get placeholder() {
        return this.i.a2;
    }
    set placeholder(v) {
        this.i.a2 = v;
    }
    /**
     * Gets or sets the color to use for the hovered text of the button regardless of type.
    */
    get hoverTextColor() {
        return brushToString(this.i.b1);
    }
    set hoverTextColor(v) {
        this.i.b1 = stringToBrush(v);
    }
    /**
     * Gets or sets the id to use for the checkbox.
    */
    get id() {
        return this.i.ay;
    }
    set id(v) {
        this.i.ay = v;
    }
    /**
     * Gets or sets TabIndex to use for the checkbox.
    */
    get tabIndex() {
        return this.i.ag;
    }
    set tabIndex(v) {
        this.i.ag = +v;
    }
    /**
     * Gets or sets the for attribute to use for the input.
    */
    get for() {
        return this.i.av;
    }
    set for(v) {
        this.i.av = v;
    }
    /**
     * Gets or sets the value of the aria-label attribute.
    */
    get ariaLabel() {
        return this.i.as;
    }
    set ariaLabel(v) {
        this.i.as = v;
    }
    /**
     * Gets or sets whether the input is hovered.
    */
    get isHover() {
        return this.i.ad;
    }
    set isHover(v) {
        this.i.ad = ensureBool(v);
    }
    /**
     * Gets or sets the value for the input.
    */
    get value() {
        return this.i.ba;
    }
    set value(v) {
        this.i.ba = v;
    }
    get hasValue() {
        return this.i.ab;
    }
    /**
     * Gets or sets whether the checkbox is disabled.
    */
    get disabled() {
        return this.i.disabled;
    }
    set disabled(v) {
        this.i.disabled = ensureBool(v);
    }
    onDetachedFromUI() {
        this.i.onDetachedFromUI();
    }
    onAttachedToUI() {
        this.i.onAttachedToUI();
    }
    get change() {
        return this._change;
    }
    set change(ev) {
        if (this._change_wrapped !== null) {
            this.i.change = delegateRemove(this.i.change, this._change_wrapped);
            this._change_wrapped = null;
            this._change = null;
        }
        this._change = ev;
        this._change_wrapped = (o, e) => {
            let outerArgs = new IgrInputChangeEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChange) {
                this.beforeChange(this, outerArgs);
            }
            if (this._change) {
                this._change(this, outerArgs);
            }
        };
        this.i.change = delegateCombine(this.i.change, this._change_wrapped);
    }
    get changing() {
        return this._changing;
    }
    set changing(ev) {
        if (this._changing_wrapped !== null) {
            this.i.changing = delegateRemove(this.i.changing, this._changing_wrapped);
            this._changing_wrapped = null;
            this._changing = null;
        }
        this._changing = ev;
        this._changing_wrapped = (o, e) => {
            let outerArgs = new IgrInputChangeEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChanging) {
                this.beforeChanging(this, outerArgs);
            }
            if (this._changing) {
                this._changing(this, outerArgs);
            }
        };
        this.i.changing = delegateCombine(this.i.changing, this._changing_wrapped);
    }
}
//# sourceMappingURL=igr-input.js.map
