import * as React from 'react';
import { Label } from "./Label";
import { ensureEnum, brushToString, stringToBrush, ensureBool, NamePatcher, isValidProp, getModifiedProps } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgrInputGroupItem } from './igr-input-group-item';
import { ControlDisplayDensity_$type } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
export class IgrLabel extends IgrInputGroupItem {
    constructor(props) {
        super(props);
        this._wrapper = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this._getMainRef = this._getMainRef.bind(this);
        var container;
        if (document) {
            container = document.createElement("div");
        }
        var root;
        root = container;
        if (container != null) {
            root = container;
        }
        this.requestRender = this.requestRender.bind(this);
        this._portalManager = new PortalManager("labelContent", this.requestRender);
        var ren = new ReactRenderer(root, document, true, {}, this._portalManager);
        this._wrapper = ren;
        this._container = this._wrapper.rootWrapper;
        this._container.setStyleProperty("display", "inline-block");
        this._container.setStyleProperty("vertical-align", "middle");
        var label = this.i;
        this._label = label;
        label.provideContainer(ren);
        if (props) {
            this.initializeProperties();
        }
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let div = React.createElement("div", {
            className: "ig-label igr-label",
            ref: this._getMainRef,
            children: children
        });
        return div;
    }
    requestRender() {
        if (this._initialized) {
            this.setState({});
        }
    }
    //private _getLabelPortal(element: DomWrapper, portalCallback: (portal: DomPortal) => void): void {
    //    this._portalManager.getPortal(element, "TemplateContent", portalCallback);
    //}
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    initializeProperties() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    // supports angular themes or custom properties set in CSS
    updateStyle() {
        this._styling(this._elRef, this);
    }
    componentWillUnmount() {
        this._label.destroy();
        this._wrapper.destroy();
    }
    componentDidMount() {
        this._elRef.appendChild(this._container.getNativeElement());
        this.initializeContent();
    }
    initializeContent() {
        this._styling(this._container.getNativeElement(), this);
        this.updateStyle();
    }
    createImplementation() {
        return new Label();
    }
    _onDisplayChanged() {
        this._container.setStyleProperty("display", this.display);
    }
    _onFlexDirectionChanged() {
        this._container.setStyleProperty("flex-direction", this.flexDirection);
    }
    _onFlexGrowChanged() {
        this._container.setStyleProperty("flex-grow", this.flexGrow);
    }
    _onAlignItemsChanged() {
        this._container.setStyleProperty("align-items", this.alignItems);
    }
    /**
                             * @hidden
                             */
    get i() {
        return this._implementation;
    }
    /**
 * Gets or sets the base built in theme to use for the label.
*/
    get baseTheme() {
        return this.i.l;
    }
    set baseTheme(v) {
        this.i.l = ensureEnum(BaseControlTheme_$type, v);
    }
    /**
     * Gets or sets the display density to use for the label.
    */
    get density() {
        return this.i.p;
    }
    set density(v) {
        this.i.p = ensureEnum(ControlDisplayDensity_$type, v);
    }
    /**
     * Gets the actual display density to use for the label.
    */
    get actualDensity() {
        return this.i.o;
    }
    set actualDensity(v) {
        this.i.o = ensureEnum(ControlDisplayDensity_$type, v);
    }
    /**
     * Gets the actual color to use for the text color.
    */
    get actualTextColor() {
        return brushToString(this.i.ct);
    }
    set actualTextColor(v) {
        this.i.ct = stringToBrush(v);
    }
    /**
     * Gets the actual color to use for the text color.
    */
    get actualHighlightTextColor() {
        return brushToString(this.i.cq);
    }
    set actualHighlightTextColor(v) {
        this.i.cq = stringToBrush(v);
    }
    /**
     * Gets the actual color to use for the text color when highlighted and hovered.
    */
    get actualHoverHighlightTextColor() {
        return brushToString(this.i.cr);
    }
    set actualHoverHighlightTextColor(v) {
        this.i.cr = stringToBrush(v);
    }
    /**
     * Gets the actual hover color to use for the text.
    */
    get actualHoverTextColor() {
        return brushToString(this.i.cs);
    }
    set actualHoverTextColor(v) {
        this.i.cs = stringToBrush(v);
    }
    /**
     * Gets the text style to use for the button.
    */
    get actualTextStyle() {
        return this.i.v;
    }
    set actualTextStyle(v) {
        this.i.v = v;
    }
    /**
     * Gets or sets the color to use for the text.
    */
    get textColor() {
        return brushToString(this.i.c9);
    }
    set textColor(v) {
        this.i.c9 = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the text.
    */
    get highlightTextColor() {
        return brushToString(this.i.c6);
    }
    set highlightTextColor(v) {
        this.i.c6 = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the text.
    */
    get hoverHighlightTextColor() {
        return brushToString(this.i.c7);
    }
    set hoverHighlightTextColor(v) {
        this.i.c7 = stringToBrush(v);
    }
    /**
     * Gets or sets the use for the button.
    */
    get textStyle() {
        return this.i.x;
    }
    set textStyle(v) {
        this.i.x = v;
    }
    /**
     * Gets or sets the type to use for the label.
    */
    get type() {
        return this.i.b0;
    }
    set type(v) {
        this.i.b0 = v;
    }
    /**
     * Gets or sets the color to use for the hovered text of the button regardless of type.
    */
    get hoverTextColor() {
        return brushToString(this.i.c8);
    }
    set hoverTextColor(v) {
        this.i.c8 = stringToBrush(v);
    }
    /**
     * Gets or sets the id to use for the checkbox.
    */
    get id() {
        return this.i.bo;
    }
    set id(v) {
        this.i.bo = v;
    }
    /**
     * Gets or sets the id to use for the checkbox.
    */
    get display() {
        return this.i.bd;
    }
    set display(v) {
        this.i.bd = v;
    }
    /**
     * Gets or sets the id to use for the checkbox.
    */
    get flexDirection() {
        return this.i.bf;
    }
    set flexDirection(v) {
        this.i.bf = v;
    }
    /**
     * Gets or sets the flex-grow setting for the button.
    */
    get flexGrow() {
        return this.i.bh;
    }
    set flexGrow(v) {
        this.i.bh = v;
    }
    /**
     * Gets or sets the id to use for the checkbox.
    */
    get alignItems() {
        return this.i.a7;
    }
    set alignItems(v) {
        this.i.a7 = v;
    }
    /**
     * Gets or sets TabIndex to use for the checkbox.
    */
    get tabIndex() {
        return this.i.aq;
    }
    set tabIndex(v) {
        this.i.aq = +v;
    }
    /**
     * Gets or sets the for attribute to use for the label.
    */
    get for() {
        return this.i.bj;
    }
    set for(v) {
        this.i.bj = v;
    }
    /**
     * Gets or sets the value of the aria-label attribute.
    */
    get ariaLabel() {
        return this.i.a9;
    }
    set ariaLabel(v) {
        this.i.a9 = v;
    }
    /**
     * Gets or sets the text for the label.
    */
    get text() {
        return this.i.text;
    }
    set text(v) {
        this.i.text = v;
    }
    /**
     * Gets or sets whether the label is hovered.
    */
    get isHover() {
        return this.i.al;
    }
    set isHover(v) {
        this.i.al = ensureBool(v);
    }
    /**
     * Gets or sets the value for the label.
    */
    get value() {
        return this.i.ao;
    }
    set value(v) {
        this.i.ao = ensureBool(v);
    }
    /**
     * Gets or sets whether the checkbox is disabled.
    */
    get disabled() {
        return this.i.disabled;
    }
    set disabled(v) {
        this.i.disabled = ensureBool(v);
    }
    onDetachedFromUI() {
        this.i.onDetachedFromUI();
    }
    onAttachedToUI() {
        this.i.onAttachedToUI();
    }
}
//# sourceMappingURL=igr-label.js.map
